reverse-type
============

Reverses the text given as command line arguments and embeds it in Unicode right-to-left marks
such that in Unicode-aware environments it displays as specified.

You might use this in environments that do auto-censoring.
